@@ -9,6 +9,7 @@ import glob
 import lammps_step
 import logging
 from math import sqrt, exp, degrees, radians, cos, acos
+# import numpy
 import seamm
 from seamm import data
 import seamm_util
@@ -19,11 +20,10 @@ import os
 import os.path
 import pandas
 import pprint
-import statsmodels.stats.stattools
-import statsmodels.api
-import statsmodels.tools
+import statsmodels.tsa.stattools as stattools
 import sys
-import warnings
+
+from pymbar import timeseries
 
 logger = logging.getLogger(__name__)
 job = printing.getPrinter()
@@ -59,45 +59,6 @@ improper_style = {
     'wilson_out_of_plane': 'class2',
 }
 
-lammps_units = {
-    'real':
-        {
-            '[mass]': 'g/mol',
-            '[distance]': 'Å',
-            '[time]': 'fs',
-            '[length] ** 2 * [mass] / [substance] / [time] ** 2': 'kcal/mol',
-            '[length] ** 2 * [mass] / [time] ** 2': 'kcal/mol',
-            '[length] / [time]': 'Å/fs',
-            '[length] * [mass] / [substance] / [time] ** 2': 'kcal/mol/Å',
-            '[length] * [mass] / [time] ** 2': 'kcal/mol/Å',
-            '[temperature]': 'K',
-            '[mass] / [length] / [time] ** 2': 'bar',
-            '[mass] / [length] / [time]': 'poise',
-            '[current] * [time]': 'e',
-            '[current] * [length] * [time]': 'e*Å',
-            '[length] * [mass] / [current] / [time] ** 3': 'V/Å',
-            '[mass] / [length] ** 3': 'g/mL'
-        },
-    'metal':
-        {
-            '[mass]': 'g/mol',
-            '[distance]': 'Å',
-            '[time]': 'ps',
-            '[length] ** 2 * [mass] / [substance] / [time] ** 2': 'eV',
-            '[length] ** 2 * [mass] / [time] ** 2': 'eV',
-            '[length] / [time]': 'Å/ps',
-            '[length] * [mass] / [substance] / [time] ** 2': 'eV/Å',
-            '[length] * [mass] / [time] ** 2': 'eV/Å',
-            '[temperature]': 'K',
-            '[mass] / [length] / [time] ** 2': 'atm',
-            '[mass] / [length] / [time]': 'poise',
-            '[current] * [time]': 'e',
-            '[current] * [length] * [time]': 'e*Å',
-            '[length] * [mass] / [current] / [time] ** 3': 'V/Å',
-            '[mass] / [length] ** 3': 'g/mL'
-        }
-}
-
 
 class LAMMPS(seamm.Node):
     display_units = {
@@ -247,7 +208,6 @@ class LAMMPS(seamm.Node):
         self.subflowchart = seamm.Flowchart(
             parent=self, name='LAMMPS', namespace=namespace
         )
-        self.lammps_units = 'real'
         self._data = {}
 
         self.maxlags = 100
@@ -400,9 +360,9 @@ class LAMMPS(seamm.Node):
                 use_mpi = False
             else:
                 if 'seamm_mpi_max_np' in o:
-                    max_np = o.seamm_mpi_max_np
+                    max_np = int(o.seamm_mpi_max_np)
                 elif 'lammps_mpi_max_np' in o:
-                    max_np = o.lammps_mpi_max_np
+                    max_np = int(o.lammps_mpi_max_np)
                 else:
                     max_np = 'default'
 
@@ -416,6 +376,8 @@ class LAMMPS(seamm.Node):
                 logger.info(
                     'The maximum number of cores to use is {}'.format(max_np)
                 )
+                if np > max_np:
+                    np = max_np
 
         if use_mpi:
             if 'lammps_mpiexec' in o:
@@ -429,7 +391,7 @@ class LAMMPS(seamm.Node):
         printer.important(self.header)
         if use_mpi:
             printer.important(
-                '   LAMMPS using MPI with {} processes.\n'.format(np)
+                '    LAMMPS using MPI with {} processes.\n'.format(np)
             )
         else:
             printer.important('   LAMMPS using the serial version.\n')
@@ -439,6 +401,8 @@ class LAMMPS(seamm.Node):
 
         self.subflowchart.root_directory = self.flowchart.root_directory
 
+        files = {}
+
         # Get the first real node
         node = self.subflowchart.get_node('1').next()
 
@@ -479,6 +443,11 @@ class LAMMPS(seamm.Node):
                 shake = self.shake_fix(P, eex)
                 if shake != '':
                     extras['shake'] = shake
+
+                # Get the structure file from the eex. Need to do this now
+                # so that we have the atomic masses later for timestep.
+                files['structure.dat'] = '\n'.join(self.structure_data(eex))
+                logger.debug('structure.dat:\n' + files['structure.dat'])
             else:
                 try:
                     input_data += node.get_input(extras)
@@ -514,12 +483,8 @@ class LAMMPS(seamm.Node):
         )
         input_data.append('')
 
-        files = {'molssi.dat': '\n'.join(input_data)}
-        logger.debug('molssi.dat:\n' + files['molssi.dat'])
-
-        # Get the structure file from the eex
-        files['structure.dat'] = '\n'.join(self.structure_data(eex))
-        logger.debug('structure.dat:\n' + files['structure.dat'])
+        files['input.txt'] = '\n'.join(input_data)
+        logger.debug('input.txt:\n' + files['input.txt'])
 
         os.makedirs(self.directory, exist_ok=True)
         for filename in files:
@@ -528,9 +493,9 @@ class LAMMPS(seamm.Node):
         local = seamm.ExecLocal()
         return_files = ['summary_*.txt', 'trajectory_*.seamm_trj', 'dump*.txt']
         if use_mpi:
-            cmd = [mpiexec, '-np', str(np), o.lammps_mpi, '-in', 'molssi.dat']
+            cmd = [mpiexec, '-np', str(np), o.lammps_mpi, '-in', 'input.txt']
         else:
-            cmd = [o.lammps_serial, '-in', 'molssi.dat']
+            cmd = [o.lammps_serial, '-in', 'input.txt']
 
         result = local.run(cmd=cmd, files=files, return_files=return_files)
 
@@ -637,48 +602,59 @@ class LAMMPS(seamm.Node):
         lines.append('Atoms')
         lines.append('')
 
-        for i, xyz_index, q in zip(
-            range(1, eex['n_atoms'] + 1), eex['atoms'], eex['charges']
-        ):
-            x, y, z, index = xyz_index
-            lines.append(
-                '{:6d} {:6d} {:6d} {:6.3f} {:12.7f} {:12.7f} {:12.7f}'.format(
-                    i, 1, index, q, x, y, z
+        if 'charges' in eex:
+            for i, xyz_index, q in zip(
+                range(1, eex['n_atoms'] + 1), eex['atoms'], eex['charges']
+            ):
+                x, y, z, index = xyz_index
+                # The '1' is molecule ID ... should correct at some point!
+                lines.append(
+                    f'{i:6d}      1 {index:6d} {q:6.3f} {x:12.7f} {y:12.7f} '
+                    f'{z:12.7f}'
                 )
-            )
+        else:
+            for i, xyz_index in enumerate(eex['atoms']):
+                x, y, z, index = xyz_index
+                lines.append(
+                    f'{i+1:6d} {index:6d} {x:12.7f} {y:12.7f} {z:12.7f}'
+                )
+            pass
         lines.append('')
 
         lines.append('Masses')
         lines.append('')
+        self._data['masses'] = []
         for i, parameters in zip(
             range(1, eex['n_atom_types'] + 1), eex['masses']
         ):
             mass, itype = parameters
             lines.append('{:6d} {} # {}'.format(i, mass, itype))
+            self._data['masses'].append(mass)
 
         # nonbonds
-        lines.append('')
-        lines.append('Pair Coeffs')
-        lines.append('')
-        for i, parameters in zip(
-            range(1, eex['n_atom_types'] + 1), eex['nonbond parameters']
-        ):
-            form, values, types, parameters_type, real_types = \
-                parameters
-            if form == 'nonbond(9-6)':
-                lines.append(
-                    '{:6d} {} {} # {} --> {}'.format(
-                        i, values['eps'], values['rmin'], types[0],
-                        real_types[0]
+        if 'nonbond_parameters' in eex:
+            lines.append('')
+            lines.append('Pair Coeffs')
+            lines.append('')
+            for i, parameters in zip(
+                range(1, eex['n_atom_types'] + 1), eex['nonbond parameters']
+            ):
+                form, values, types, parameters_type, real_types = \
+                    parameters
+                if form == 'nonbond(9-6)':
+                    lines.append(
+                        '{:6d} {} {} # {} --> {}'.format(
+                            i, values['eps'], values['rmin'], types[0],
+                            real_types[0]
+                        )
                     )
-                )
-            else:
-                lines.append(
-                    '{:6d} {} {} # {} --> {}'.format(
-                        i, values['eps'], values['sigma'], types[0],
-                        real_types[0]
+                else:
+                    lines.append(
+                        '{:6d} {} {} # {} --> {}'.format(
+                            i, values['eps'], values['sigma'], types[0],
+                            real_types[0]
+                        )
                     )
-                )
 
         # bonds
         if 'n_bonds' in eex and eex['n_bonds'] > 0:
@@ -1127,16 +1103,6 @@ class LAMMPS(seamm.Node):
         lines.append('')
         return lines
 
-    def to_lammps_units(self, value):
-        dimensionality = str(value.dimensionality)
-        return value.to(lammps_units[self.lammps_units][dimensionality])
-
-    def magnitude_in_lammps_units(self, value):
-        if isinstance(value, units_class):
-            return self.to_lammps_units(value).magnitude
-        else:
-            return value
-
     def analyze(self, indent='', **kwargs):
         """Analyze the output of the calculation
         """
@@ -1168,9 +1134,9 @@ class LAMMPS(seamm.Node):
     def analyze_trajectory(self, filename, sampling_rate=20):
         """Read a trajectory file and do the statistical analysis
         """
-        import seamm_util.md_statistics as md_statistics
-
-        write_html = 'lammps_html' in self.options
+        write_html = (
+            'lammps_html' in self.options and self.options.lammps_html
+        )
         rootname = os.path.splitext(filename)[0]
         results = {}
 
@@ -1192,111 +1158,150 @@ class LAMMPS(seamm.Node):
         )
 
         printer.normal(
-            '               Property           Value       stderr    tau   '
-            ' ineff\n'
-            '          --------------------   ---------   ------- -------- '
-            ' ------'
+            '                                             Std Error  '
+            'Time to\n'
+            '               Property           Value       of mean   '
+            'convergence     tau    inefficiency\n'
+            '          --------------------   ---------  ---------   '
+            '-----------  --------  ------------'
         )
-        correlation = {}
-        summary_file = rootname + '.summary'
-        with open(summary_file, 'w') as fd:
-            x = data.index
-            for column in data.columns[1:]:
-                y = data[column]
-
-                # Find the autocorrelation time...
-                t_delta = x[1] - x[0]
-                acf = md_statistics.analyze_autocorrelation(
-                    y, method='zr', nlags=16, interval=t_delta
-                )
-                correlation[column] = acf
-
-                for key, value in acf.items():
-                    if 'acf' not in key and 'confidence' not in key:
-                        results['{},{}'.format(column, key)] = value
-
-                # And get the statistics accounting for the correlation
-                n_step = int(round(acf['inefficiency']))
-
-                x0 = statsmodels.tools.add_constant(data.index[::n_step])
-                y0 = data[column][::n_step]
-                model = statsmodels.api.OLS(y0, x0)
-                fit = model.fit()
-
-                results[column] = fit.params['const']
-
-                # Convert warnings to errors, for statsmodels.
-                with warnings.catch_warnings():
-                    warnings.filterwarnings('error')
-                    try:
-                        bse = fit.bse['const']
-                    except Exception:
-                        bse = float('Inf')
-                    results['{},stderr'.format(column)] = bse
-
-                fd.write(
-                    'Summary of statistics for {} n_step = {}\n'.format(
-                        column, n_step
-                    )
-                )
-
-                # Convert warnings to errors, for statsmodels.
-                with warnings.catch_warnings():
-                    warnings.filterwarnings('error')
-                    try:
-                        fd.write('{}\n\n'.format(fit.summary()))
-                    except Exception as e:
-                        fd.write('{}\n\n'.format(str(e)))
-
-                printer.normal(
-                    __(
-                        '{column:>23s} = {value:9.3f} ± {stderr:7.3f}'
-                        ' {tau:8.1f} {inefficiency:7.1f}',
-                        column=column,
-                        value=fit.params['const'],
-                        stderr=bse,
-                        **acf,
-                        indent=7 * ' ',
-                        wrap=False,
-                        dedent=False
-                    )
-                )
-
-                if False:
-                    result = statsmodels.tsa.stattools.adfuller(y0)
-                    print(
-                        '\n\t   Testing Convergence with Augmented '
-                        'Dickey-Fuller method',
-                        file=fd
-                    )
-                    print('\tADF Statistic: %f' % result[0], file=fd)
-                    print('\tp-value: %f' % result[1], file=fd)
-                    print('\tCritical Values:', file=fd)
-                    for key, value in result[4].items():
-                        print('\t\t%2s: %.3f' % (key, value), file=fd)
-                    print('\n\n\n', file=fd)
-
-        # Create graphs of the property
 
         # Work out the time step, rather than give the whole vector
         t = data.index
-        dt_raw = t[1] - t[0]
-        dt = dt_raw
+        dt_fs = lammps_step.from_lammps_units(
+            t[1] - t[0], 'fs', quantity='time'
+        ).magnitude
+        dt = dt_fs
         t_units = 'fs'
-        len_trj = (len(t) - 1) * dt_raw
-        if len_trj >= 10000000000:
+        len_trj = (len(t) - 1) * dt_fs
+        divisor = 1
+        if len_trj >= 4000000000:
             t_units = 'ms'
-            dt /= 1000000000
-        elif len_trj >= 10000000:
+            divisor = 1000000000
+        elif len_trj >= 4000000:
             t_units = 'ns'
-            dt /= 1000000
-        elif len_trj >= 10000:
+            divisor = 1000000
+        elif len_trj >= 4000:
             t_units = 'ps'
-            dt /= 1000
+            divisor = 1000
+        dt /= divisor
         t_max = float((len(t) - 1) * dt)
 
+        have_warning = False
+        have_acf_warning = False
         for column in data.columns[1:]:
-            logger.debug('Column = ' + column)
+            y = data[column]
+
+            logger.info('Analyzing {}, nsamples = {}'.format(column, len(y)))
+
+            # compute indices of uncorrelated timeseries using pymbar
+            yy = y.to_numpy()
+            conv, inefficiency, Neff_max = timeseries.detectEquilibration(yy)
+
+            logger.info(
+                '  converged in {} steps, inefficiency = {}, Neff_max = {}'
+                .format(conv, inefficiency, Neff_max)
+            )
+            tau = dt_fs * (inefficiency - 1) / 2
+            if tau < dt_fs / 2:
+                tau = dt_fs / 2
+            t0 = conv * dt_fs
+            y_t_equil = yy[conv:]
+            indices = timeseries.subsampleCorrelatedData(
+                y_t_equil, g=inefficiency
+            )
+            if len(indices) == 0:
+                print('Problem with column ' + column)
+                print('yy')
+                print(yy)
+                print('y_t_equil')
+                print(y_t_equil)
+                print('indices')
+                print(indices)
+                continue
+            y_n = y_t_equil[indices]
+            n_samples = len(y_n)
+            mean = y_n.mean()
+            std = y_n.std()
+            sem = std / sqrt(n_samples)
+
+            # Get the autocorrelation function
+            if len(y_t_equil) < 8:
+                have_acf = False
+                have_acf_warning = True
+                acf_warning = '^'
+            else:
+                have_acf = True
+                acf_warning = ' '
+                nlags = 4 * int(round(inefficiency + 0.5))
+                if nlags > int(len(y_t_equil) / 2):
+                    nlags = int(len(y_t_equil) / 2)
+                acf, confidence = stattools.acf(
+                    y_t_equil,
+                    nlags=nlags,
+                    alpha=0.05,
+                    fft=nlags > 16,
+                    unbiased=False
+                )
+
+            results[column] = mean
+            results['{},stderr'.format(column)] = sem
+            results['{},n_sample'.format(column)] = n_samples
+
+            # Work out units on convergence time
+            conv_units = 'fs'
+            t_conv = t0
+            if t0 >= 1000000000:
+                conv_units = 'ms'
+                t_conv = t0 / 1000000000
+            elif t0 >= 1000000:
+                conv_units = 'ns'
+                t_conv = t0 / 1000000
+            elif t0 >= 1000:
+                conv_units = 'ps'
+                t_conv = t0 / 1000
+
+            # Work out units on autocorrelation time
+            tau_units = 'fs'
+            t_tau = tau
+            if tau >= 1000000000:
+                tau_units = 'ms'
+                t_tau = tau / 1000000000
+            elif tau >= 1000000:
+                tau_units = 'ns'
+                t_tau = tau / 1000000
+            elif tau >= 1000:
+                tau_units = 'ps'
+                t_tau = tau / 1000
+
+            if n_samples < 100:
+                have_warning = True
+                warn = '*'
+            else:
+                warn = ' '
+
+            printer.normal(
+                __(
+                    '{column:>23s} = {value:9.3f} ± {stderr:7.3f}{warn}'
+                    ' {t0:8.2f} {conv_units} {tau:8.1f} {tau_units}{acf} '
+                    '{inefficiency:9.1f}',
+                    column=column,
+                    value=mean,
+                    stderr=sem,
+                    warn=warn,
+                    t0=t_conv,
+                    conv_units=conv_units,
+                    tau=t_tau,
+                    tau_units=tau_units,
+                    acf=acf_warning,
+                    inefficiency=inefficiency,
+                    indent=7 * ' ',
+                    wrap=False,
+                    dedent=False
+                )
+            )
+
+            # Create graphs of the property
             figure = self.create_figure(
                 module_path=(self.__module__.split('.')[0], 'seamm'),
                 template='line.graph_template',
@@ -1304,104 +1309,92 @@ class LAMMPS(seamm.Node):
             )
 
             # The autocorrelation function
-            plot_acf = figure.add_plot('acf')
+            if have_acf:
+                plot_acf = figure.add_plot('acf')
 
-            acf = correlation[column]
+                dt_acf = float(dt_fs)
+                t_acf_units = 'fs'
+                len_acf = (len(acf) - 1) * dt_fs
+                if len_acf >= 2000000000:
+                    t_acf_units = 'ms'
+                    dt_acf /= 1000000000
+                elif len_acf >= 2000000:
+                    t_acf_units = 'ns'
+                    dt_acf /= 1000000
+                elif len_acf >= 2000:
+                    t_acf_units = 'ps'
+                    dt_acf /= 1000
 
-            inefficiency = acf['inefficiency']
-            n_step = int(round(inefficiency))
-            n_c = acf['n_c']
+                x_acf_axis = plot_acf.add_axis(
+                    'x', label='Time ({})'.format(t_acf_units)
+                )
+                y_acf_axis = plot_acf.add_axis(
+                    'y', label='acf', anchor=x_acf_axis
+                )
+                x_acf_axis.anchor = y_acf_axis
 
-            len_acf = 3 * n_c
-            if len_acf < 19:
-                len_acf = 19
-            if len_acf > len(y):
-                len_acf = len(y)
+                # Put the fit to the autocorrelation time in first so the
+                # subsequent trajectory trace sits in top
+                ts = 0.0
+                fit = [1.0]
+                for step in range(len(acf) - 1):
+                    ts += dt_fs
+                    fit.append(exp(-ts / tau))
 
-            y = [1.0] + list(acf['acf'])[:len_acf]
+                plot_acf.add_trace(
+                    x_axis=x_acf_axis,
+                    y_axis=y_acf_axis,
+                    name='fit',
+                    x0=0,
+                    dx=dt_acf,
+                    xlabel='t',
+                    xunits=t_acf_units,
+                    y=fit,
+                    ylabel='fit',
+                    yunits='',
+                    color='gray'
+                )
 
-            dt_acf = float(dt_raw)
-            t_acf_units = 'fs'
-            len_acf = (len(y) - 1) * dt_raw
-            if len_acf >= 2000000000:
-                t_acf_units = 'ms'
-                dt_acf /= 1000000000
-            elif len_acf >= 2000000:
-                t_acf_units = 'ns'
-                dt_acf /= 1000000
-            elif len_acf >= 2000:
-                t_acf_units = 'ps'
-                dt_acf /= 1000
+                # the partly transparent error band
+                yplus = []
+                yminus = []
+                t_acf = []
+                tmp = 0.0
+                for lower, upper in confidence:
+                    t_acf.append(tmp)
+                    yplus.append(upper)
+                    yminus.append(lower)
+                    tmp += dt_acf
 
-            x_acf_axis = plot_acf.add_axis(
-                'x', label='Time ({})'.format(t_acf_units)
-            )
-            y_acf_axis = plot_acf.add_axis('y', label='acf', anchor=x_acf_axis)
-            x_acf_axis.anchor = y_acf_axis
+                plot_acf.add_trace(
+                    x_axis=x_acf_axis,
+                    y_axis=y_acf_axis,
+                    name='stderr',
+                    x=t_acf + t_acf[::-1],
+                    xlabel='t',
+                    xunits=t_acf_units,
+                    y=yplus + yminus[::-1],
+                    ylabel='stderr',
+                    yunits=LAMMPS.display_units[column],
+                    showlegend='false',
+                    color='rgba(211,211,211,0.5)',
+                    fill='toself',
+                )
 
-            # Put the fit to the autocorrelation time in first so the
-            # subsequent trajectory trce sits in top
-            tau = acf['tau']
-            t = 0.0
-            fit = []
-            for step in range(len(y)):
-                fit.append(exp(-t / tau))
-                t += dt_raw
-
-            plot_acf.add_trace(
-                x_axis=x_acf_axis,
-                y_axis=y_acf_axis,
-                name='fit',
-                x0=0,
-                dx=dt_acf,
-                xlabel='t',
-                xunits=t_acf_units,
-                y=fit,
-                ylabel='fit',
-                yunits='',
-                color='gray'
-            )
-
-            # the partly transparent error band
-            yplus = [1]
-            yminus = [1]
-            t_acf = [0.0]
-            tmp = 0.0
-            for lower, upper in acf['confidence_interval']:
-                tmp += dt_acf
-                t_acf.append(tmp)
-                yplus.append(upper)
-                yminus.append(lower)
-
-            plot_acf.add_trace(
-                x_axis=x_acf_axis,
-                y_axis=y_acf_axis,
-                name='stderr',
-                x=t_acf + t_acf[::-1],
-                xlabel='t',
-                xunits=t_acf_units,
-                y=yplus + yminus[::-1],
-                ylabel='stderr',
-                yunits=LAMMPS.display_units[column],
-                showlegend='false',
-                color='rgba(211,211,211,0.5)',
-                fill='toself',
-            )
-
-            # And the acf plot last
-            plot_acf.add_trace(
-                x_axis=x_acf_axis,
-                y_axis=y_acf_axis,
-                name='acf',
-                x0=0,
-                dx=dt_acf,
-                xlabel='t',
-                xunits=t_acf_units,
-                y=y,
-                ylabel='acf',
-                yunits='',
-                color='red'
-            )
+                # And the acf plot last
+                plot_acf.add_trace(
+                    x_axis=x_acf_axis,
+                    y_axis=y_acf_axis,
+                    name='acf',
+                    x0=0,
+                    dx=dt_acf,
+                    xlabel='t',
+                    xunits=t_acf_units,
+                    y=list(acf),
+                    ylabel='acf',
+                    yunits='',
+                    color='red'
+                )
 
             # The property data over the trajectory
             y = list(data[column])
@@ -1419,9 +1412,6 @@ class LAMMPS(seamm.Node):
             # Add the trajectory, error band and median value in that order so
             # stack in a nice order.
 
-            value = results[column]
-            stderr = results[column + ',stderr']
-
             # Add the trajectory
             plot.add_trace(
                 x_axis=x_axis,
@@ -1438,18 +1428,16 @@ class LAMMPS(seamm.Node):
             )
 
             # the partly transparent error band
+            t_min = t0 / divisor
             plot.add_trace(
                 x_axis=x_axis,
                 y_axis=y_axis,
-                name='stderr',
-                x=[0, t_max, t_max, 0],
+                name='sem',
+                x=[t_min, t_max, t_max, t_min],
                 xlabel='t',
                 xunits=t_units,
-                y=[
-                    value + stderr, value + stderr, value - stderr,
-                    value - stderr
-                ],
-                ylabel='stderr',
+                y=[mean + sem, mean + sem, mean - sem, mean - sem],
+                ylabel='sem',
                 yunits=LAMMPS.display_units[column],
                 showlegend='false',
                 color='rgba(211,211,211,0.5)',
@@ -1461,22 +1449,47 @@ class LAMMPS(seamm.Node):
                 x_axis=x_axis,
                 y_axis=y_axis,
                 name='average',
-                x=[0, t_max],
+                x=[t_min, t_max],
                 xlabel='t',
                 xunits=t_units,
-                y=[value, value],
+                y=[mean, mean],
                 ylabel='average',
                 yunits=LAMMPS.display_units[column],
                 color='black'
             )
 
-            figure.grid_plots('trj - acf')
+            if have_acf:
+                figure.grid_plots('trj - acf')
+            else:
+                figure.grid_plots('trj')
             figure.dump('{}_{}.graph'.format(rootname, column))
 
             if write_html:
                 figure.template = 'line.html_template'
                 figure.dump('{}_{}.html'.format(rootname, column))
 
+        if have_warning or have_acf_warning:
+            printer.normal('\n')
+        if have_warning:
+            printer.normal(
+                __(
+                    '          * this property has less than 100 independent '
+                    'samples, so may not be accurate.',
+                    wrap=False,
+                    dedent=False
+                )
+            )
+
+        if have_acf_warning:
+            printer.normal(
+                __(
+                    '          ^ there are not enough samples after '
+                    'equilibration to plot the ACF.',
+                    wrap=False,
+                    dedent=False
+                )
+            )
+
         return results
 
     def shake_fix(self, P, eex):
